Welcome to rms-link-checker!
============================

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- start-after-point -->

.. toctree::
   :maxdepth: 2
   :caption: User's Guide:

   user/installation
   user/usage
   user/configuration
   user/report
   user/troubleshooting

.. toctree::
   :maxdepth: 2
   :caption: Developer's Guide:

   dev/setup
   dev/architecture
   dev/api
   dev/testing
   dev/contributing
   dev/releasing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
